(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common'), require('rxjs/Subject'), require('rxjs/operator/debounceTime')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core', '@angular/common', 'rxjs/Subject', 'rxjs/operator/debounceTime'], factory) :
	(factory((global.core = {}),global.ng.core,global.ng.common,global.Rx,global.Rx.Observable.prototype));
}(this, (function (exports,core,common,Subject,debounceTime) { 'use strict';

var LoadingBarService = /** @class */ (function () {
    function LoadingBarService() {
        this.progress$ = debounceTime.debounceTime.call(new Subject.Subject());
        this._pending = new Subject.Subject();
        this._pendingRequests = 0;
        this._value = 0;
    }
    /**
     * @return {?}
     */
    LoadingBarService.prototype.start = function () {
        ++this._pendingRequests;
        if (this._value === 0) {
            // Inserts the loading bar element into the dom, and sets it to 2%
            this.set(2);
        }
    };
    /**
     * @return {?}
     */
    LoadingBarService.prototype.complete = function () {
        var _this = this;
        if (this._pendingRequests === 0) {
            return;
        }
        --this._pendingRequests;
        if (this._pendingRequests === 0 && this._value !== 100) {
            if (this._value > 0) {
                this.set(100);
                // Attempt to aggregate any start/complete calls within 500ms:
                setTimeout(function () { return _this.set(0); }, 500);
            }
        }
    };
    /**
     * @return {?}
     */
    LoadingBarService.prototype.ngOnDestroy = function () {
        this.progress$.complete();
    };
    /**
     * Set the loading bar's width to a certain percent.
     *
     * @param {?} n any value between 0 and 100
     * @return {?}
     */
    LoadingBarService.prototype.set = function (n) {
        var _this = this;
        if (n === 0 && this._pendingRequests > 0) {
            n = 2;
        }
        this._value = n;
        this.progress$.next(n);
        // increment loadingbar to give the illusion that there is always
        // progress but make sure to cancel the previous timeouts so we don't
        // have multiple incs running at the same time.
        clearTimeout(this._incTimeout);
        if (this._value > 0 && this._value < 100) {
            this._incTimeout = setTimeout(function () { return _this.increment(); }, 250);
        }
    };
    /**
     * Increments the loading bar by a random amount
     * but slows down as it progresses
     * @return {?}
     */
    LoadingBarService.prototype.increment = function () {
        var /** @type {?} */ rnd = 0;
        var /** @type {?} */ stat = this._value;
        if (stat >= 0 && stat < 25) {
            // Start out between 3 - 6% increments
            rnd = (Math.random() * (5 - 3 + 1) + 3);
        }
        else if (stat >= 25 && stat < 65) {
            // increment between 0 - 3%
            rnd = (Math.random() * 3);
        }
        else if (stat >= 65 && stat < 90) {
            // increment between 0 - 2%
            rnd = (Math.random() * 2);
        }
        else if (stat >= 90 && stat < 99) {
            // finally, increment it .5 %
            rnd = 0.5;
        }
        else {
            // after 99%, don't increment:
            rnd = 0;
        }
        this.set(this._value + rnd);
    };
    return LoadingBarService;
}());
LoadingBarService.decorators = [
    { type: core.Injectable },
];
/**
 * @nocollapse
 */
LoadingBarService.ctorParameters = function () { return []; };
var LoadingBarComponent = /** @class */ (function () {
    /**
     * @param {?} loader
     */
    function LoadingBarComponent(loader) {
        this.loader = loader;
        this.includeSpinner = true;
        this.includeBar = true;
    }
    return LoadingBarComponent;
}());
LoadingBarComponent.decorators = [
    { type: core.Component, args: [{
                selector: 'ngx-loading-bar',
                template: "\n    <ng-container *ngIf=\"(loader.progress$|async) as progress\">\n      <div id=\"loading-bar-spinner\" *ngIf=\"includeSpinner\" [style.color]=\"color\"><div class=\"spinner-icon\"></div></div>\n      <div id=\"loading-bar\" *ngIf=\"includeBar\" [style.color]=\"color\">\n        <div class=\"bar\" [style.background]=\"color\" [style.width]=\"progress + '%'\">\n          <div class=\"peg\"></div>\n        </div>\n      </div>\n    </ng-container>\n  ",
                changeDetection: core.ChangeDetectionStrategy.OnPush,
            },] },
];
/**
 * @nocollapse
 */
LoadingBarComponent.ctorParameters = function () { return [
    { type: LoadingBarService, },
]; };
LoadingBarComponent.propDecorators = {
    'includeSpinner': [{ type: core.Input },],
    'includeBar': [{ type: core.Input },],
    'color': [{ type: core.Input },],
};
var LoadingBarModule = /** @class */ (function () {
    function LoadingBarModule() {
    }
    /**
     * @return {?}
     */
    LoadingBarModule.forRoot = function () {
        return {
            ngModule: LoadingBarModule,
            providers: [LoadingBarService],
        };
    };
    return LoadingBarModule;
}());
LoadingBarModule.decorators = [
    { type: core.NgModule, args: [{
                imports: [common.CommonModule],
                declarations: [LoadingBarComponent],
                exports: [LoadingBarComponent],
            },] },
];
/**
 * @nocollapse
 */
LoadingBarModule.ctorParameters = function () { return []; };

exports.LoadingBarModule = LoadingBarModule;
exports.LoadingBarComponent = LoadingBarComponent;
exports.LoadingBarService = LoadingBarService;

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=core.umd.js.map
